Home - Beobench Docs
=============================

.. include:: ../README.rst
   :start-after: start-in-sphinx-docs
   :end-before: end-in-sphinx-docs

Contents
--------

.. toctree::
   :maxdepth: 2

   self
   guides/installation
   guides
   api
   contributing
   authors
   history

Indices and tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
